@@ -15,19 +15,19 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 10
+#define ARROW_VERSION_MAJOR 15
 #define ARROW_VERSION_MINOR 0
-#define ARROW_VERSION_PATCH 1
+#define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "10.0.1"
+#define ARROW_VERSION_STRING "15.0.0"
 
-#define ARROW_SO_VERSION "1000"
-#define ARROW_FULL_SO_VERSION "1000.1.0"
+#define ARROW_SO_VERSION "1500"
+#define ARROW_FULL_SO_VERSION "1500.0.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
-#define ARROW_CXX_COMPILER_VERSION "15.0.7"
-#define ARROW_CXX_COMPILER_FLAGS "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics -O2 -DNDEBUG"
+#define ARROW_CXX_COMPILER_VERSION "16.0.6"
+#define ARROW_CXX_COMPILER_FLAGS "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics"
 
 #define ARROW_BUILD_TYPE "RELEASE"
 
@@ -51,11 +51,11 @@
 #define ARROW_PARQUET
 #define ARROW_SUBSTRAIT
 
+#define ARROW_ENABLE_THREADING
 /* #undef ARROW_GCS */
 /* #undef ARROW_S3 */
 /* #undef ARROW_USE_NATIVE_INT128 */
 /* #undef ARROW_WITH_MUSL */
 /* #undef ARROW_WITH_OPENTELEMETRY */
 /* #undef ARROW_WITH_UCX */
-
-#define GRPCPP_PP_INCLUDE
+#define PARQUET_REQUIRE_ENCRYPTION
